aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/https.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/https.rs b/src/https.rs
index 9d92470..78190b4 100644
--- a/src/https.rs
+++ b/src/https.rs
@@ -371,8 +371,8 @@ async fn do_proxy(
reverse_proxy::call(remote_addr.ip(), &to_addr, req).await?
};
- if response.status().is_success() {
- // (TODO: maybe we want to add these headers even if it's not a success?)
+ if response.status().is_success() || response.status().is_redirection() {
+ // (TODO: maybe we want to add these headers even if it's not a success or redirection?)
for (header, value) in proxy_to.add_headers.iter() {
response.headers_mut().insert(
HeaderName::from_bytes(header.as_bytes())?,